@@ -88,11 +88,27 @@ class ContextMiddleware(base.Middleware):
                 request.headers.get('X-Designate-Edit-Managed-Records')
             )
 
+    @staticmethod
+    def _extract_hard_delete(ctxt, request):
+        ctxt.hard_delete = False
+        if request.headers.get('X-Designate-Hard-Delete'):
+            ctxt.hard_delete = strutils.bool_from_string(
+                request.headers.get('X-Designate-Hard-Delete')
+            )
+
     @staticmethod
     def _extract_client_addr(ctxt, request):
         if hasattr(request, 'client_addr'):
             ctxt.client_addr = request.client_addr
 
+    @staticmethod
+    def _extract_delete_shares(ctxt, request):
+        ctxt.delete_shares = False
+        if request.headers.get('X-Designate-Delete-Shares'):
+            ctxt.delete_shares = strutils.bool_from_string(
+                request.headers.get('X-Designate-Delete-Shares')
+            )
+
     def make_context(self, request, *args, **kwargs):
         req_id = request.environ.get(request_id.ENV_REQUEST_ID)
         kwargs.setdefault('request_id', req_id)
@@ -103,8 +119,10 @@ class ContextMiddleware(base.Middleware):
             self._extract_sudo(ctxt, request)
             self._extract_all_projects(ctxt, request)
             self._extract_edit_managed_records(ctxt, request)
+            self._extract_hard_delete(ctxt, request)
             self._extract_dns_hide_counts(ctxt, request)
             self._extract_client_addr(ctxt, request)
+            self._extract_delete_shares(ctxt, request)
         finally:
             request.environ['context'] = ctxt
         return ctxt
