@@ -13,12 +13,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import time
-
 from oslo_log import log as logging
 from oslo_utils.secretutils import md5
-from sqlalchemy import select, distinct, func
-from sqlalchemy.sql.expression import or_
+from sqlalchemy import case, select, distinct, func
+from sqlalchemy.sql.expression import or_, literal_column
 
 from designate import exceptions
 from designate import objects
@@ -182,7 +180,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         return tenant_list
 
     def get_tenant(self, context, tenant_id):
-        # get list list & count of all zones owned by given tenant_id
+        # get list & count of all zones owned by given tenant_id
         query = select([tables.zones.c.name])
         query = self._apply_tenant_criteria(context, tables.zones, query)
         query = self._apply_deleted_criteria(context, tables.zones, query)
@@ -215,14 +213,23 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     # Zone Methods
     ##
     def _find_zones(self, context, criterion, one=False, marker=None,
-                    limit=None, sort_key=None, sort_dir=None):
+                    limit=None, sort_key=None, sort_dir=None,
+                    apply_tenant_criteria=True):
         # Check to see if the criterion can use the reverse_name column
         criterion = self._rname_check(criterion)
 
+        # Create a virtual column showing if the zone is shared or not.
+        shared_case = case((tables.shared_zones.c.target_project_id.is_(None),
+                            literal_column('False')),
+                           else_=literal_column('True')).label('shared')
+        query = select(
+            [tables.zones, shared_case]).outerjoin(tables.shared_zones)
+
         zones = self._find(
             context, tables.zones, objects.Zone, objects.ZoneList,
             exceptions.ZoneNotFound, criterion, one, marker, limit,
-            sort_key, sort_dir)
+            sort_key, sort_dir, query=query,
+            apply_tenant_criteria=apply_tenant_criteria)
 
         def _load_relations(zone):
             if zone.type == 'SECONDARY':
@@ -234,7 +241,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                 zone.masters = objects.ZoneMasterList()
 
             zone.attributes = self._find_zone_attributes(
-                context, {'zone_id': zone.id, "key": "!master"})
+                context, {'zone_id': zone.id, 'key': '!master'})
 
             zone.obj_reset_changes(['masters', 'attributes'])
 
@@ -249,12 +256,12 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                 _load_relations(d)
 
         if one:
-            LOG.debug("Fetched zone %s", zones)
+            LOG.debug('Fetched zone %s', zones)
         return zones
 
     def create_zone(self, context, zone):
         # Patch in the reverse_name column
-        extra_values = {"reverse_name": zone.name[::-1]}
+        extra_values = {'reverse_name': zone.name[::-1]}
 
         # Don't handle recordsets for now
         zone = self._create(
@@ -276,8 +283,9 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
         return zone
 
-    def get_zone(self, context, zone_id):
-        zone = self._find_zones(context, {'id': zone_id}, one=True)
+    def get_zone(self, context, zone_id, apply_tenant_criteria=True):
+        zone = self._find_zones(context, {'id': zone_id}, one=True,
+                                apply_tenant_criteria=apply_tenant_criteria)
         return zone
 
     def find_zones(self, context, criterion=None, marker=None, limit=None,
@@ -297,7 +305,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             tenant_id_changed = True
 
         # Don't handle recordsets for now
-        LOG.debug("Updating zone %s", zone)
+        LOG.debug('Updating zone %s', zone)
         updated_zone = self._update(
             context, tables.zones, zone, exceptions.DuplicateZone,
             exceptions.ZoneNotFound,
@@ -409,16 +417,17 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                     self.delete_recordset(context, i)
 
         if tenant_id_changed:
-            recordsets_query = tables.recordsets.update().\
-                where(tables.recordsets.c.zone_id == zone.id)\
-                .values({'tenant_id': zone.tenant_id})
-
-            records_query = tables.records.update().\
-                where(tables.records.c.zone_id == zone.id).\
+            self.session.execute(
+                tables.recordsets.update().
+                where(tables.recordsets.c.zone_id == zone.id).
                 values({'tenant_id': zone.tenant_id})
+            )
 
-            self.session.execute(records_query)
-            self.session.execute(recordsets_query)
+            self.session.execute(
+                tables.records.update().
+                where(tables.records.c.zone_id == zone.id).
+                values({'tenant_id': zone.tenant_id})
+            )
 
         return updated_zone
 
@@ -446,8 +455,8 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             current = zones_by_id[current.parent_zone_id]
             max_steps -= 1
             if max_steps == 0:
-                raise exceptions.IllegalParentZone("Loop detected in the"
-                                                   " zone hierarchy")
+                raise exceptions.IllegalParentZone('Loop detected in the'
+                                                   ' zone hierarchy')
 
         return current.parent_zone_id
 
@@ -466,10 +475,10 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             limit=limit,
         )
         if not zones:
-            LOG.info("No zones to be purged")
+            LOG.info('No zones to be purged')
             return
 
-        LOG.debug("Purging %d zones", len(zones))
+        LOG.debug('Purging %d zones', len(zones))
 
         zones_by_id = {z.id: z for z in zones}
 
@@ -477,16 +486,18 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
             # Reparent child zones, if any.
             surviving_parent_id = self._walk_up_zones(zone, zones_by_id)
-            query = tables.zones.update().\
-                where(tables.zones.c.parent_zone_id == zone.id).\
+            query = (
+                tables.zones.update().
+                where(tables.zones.c.parent_zone_id == zone.id).
                 values(parent_zone_id=surviving_parent_id)
+            )
 
             resultproxy = self.session.execute(query)
-            LOG.debug("%d child zones updated", resultproxy.rowcount)
+            LOG.debug('%d child zones updated', resultproxy.rowcount)
 
             self.purge_zone(context, zone)
 
-        LOG.info("Purged %d zones", len(zones))
+        LOG.info('Purged %d zones', len(zones))
         return len(zones)
 
     def count_zones(self, context, criterion=None):
@@ -503,6 +514,76 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
         return result[0]
 
+    # Shared zones methods
+    def _find_shared_zones(self, context, criterion, one=False, marker=None,
+                           limit=None, sort_key=None, sort_dir=None):
+
+        table = tables.shared_zones
+
+        query = select(table)
+
+        if not context.all_tenants:
+            query = query.where(or_(
+                table.c.project_id == context.project_id,
+                table.c.target_project_id == context.project_id))
+
+        return self._find(
+            context, tables.shared_zones, objects.SharedZone,
+            objects.SharedZoneList, exceptions.SharedZoneNotFound, criterion,
+            one, marker, limit, sort_key, sort_dir, query=query,
+            apply_tenant_criteria=False)
+
+    def _find_zone_share(self, context, zone):
+        criterion = {
+            "target_project_id": context.project_id,
+            "zone_id": zone.id
+        }
+
+        try:
+            return self._find(
+                context, tables.shared_zones, objects.SharedZone,
+                objects.SharedZoneList, exceptions.SharedZoneNotFound,
+                criterion,
+                one=True
+            )
+        except exceptions.SharedZoneNotFound:
+            return None
+
+    def share_zone(self, context, shared_zone):
+        return self._create(tables.shared_zones, shared_zone,
+                            exceptions.DuplicateSharedZone)
+
+    def unshare_zone(self, context, zone_id, shared_zone_id):
+        shared_zone = self._find_shared_zones(
+            context, {'id': shared_zone_id, 'zone_id': zone_id}, one=True
+        )
+        return self._delete(context, tables.shared_zones, shared_zone,
+                            exceptions.SharedZoneNotFound)
+
+    def find_shared_zones(self, context, criterion=None, marker=None,
+                          limit=None, sort_key=None, sort_dir=None):
+        return self._find_shared_zones(
+            context, criterion, marker=marker,
+            limit=limit, sort_key=sort_key, sort_dir=sort_dir
+        )
+
+    def get_shared_zone(self, context, zone_id, shared_zone_id):
+        return self._find_shared_zones(
+            context, {'id': shared_zone_id, 'zone_id': zone_id}, one=True
+        )
+
+    def is_zone_shared_with_project(self, zone_id, project_id):
+        query = select(literal_column('true'))
+        query = query.where(tables.shared_zones.c.zone_id == zone_id)
+        query = query.where(
+            tables.shared_zones.c.target_project_id == project_id)
+        return self.session.scalar(query) is not None
+
+    def delete_zone_shares(self, zone_id):
+        query = tables.shared_zones.delete().where(
+            tables.shared_zones.c.zone_id == zone_id)
+        self.session.execute(query)
+
     # Zone attribute methods
     def _find_zone_attributes(self, context, criterion, one=False,
                               marker=None, limit=None, sort_key=None,
@@ -527,9 +608,6 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                                           limit=limit, sort_key=sort_key,
                                           sort_dir=sort_dir)
 
-    def find_zone_attribute(self, context, criterion):
-        return self._find_zone_attributes(context, criterion, one=True)
-
     def update_zone_attribute(self, context, zone_attribute):
         return self._update(context, tables.zone_attributes,
                             zone_attribute,
@@ -556,26 +634,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                           marker, limit, sort_key, sort_dir)
 
     def create_zone_master(self, context, zone_id, zone_master):
-
         zone_master.zone_id = zone_id
         return self._create(tables.zone_masters, zone_master,
                             exceptions.DuplicateZoneMaster)
 
-    def get_zone_masters(self, context, zone_attribute_id):
-        return self._find_zone_masters(
-            context, {'id': zone_attribute_id}, one=True)
-
-    def find_zone_masters(self, context, criterion=None, marker=None,
-                          limit=None, sort_key=None, sort_dir=None):
-        return self._find_zone_masters(context, criterion, marker=marker,
-                                       limit=limit, sort_key=sort_key,
-                                       sort_dir=sort_dir)
-
-    def find_zone_master(self, context, criterion):
-        return self._find_zone_master(context, criterion, one=True)
-
     def update_zone_master(self, context, zone_master):
-
         return self._update(context, tables.zone_masters,
                             zone_master,
                             exceptions.DuplicateZoneMaster,
@@ -593,13 +656,12 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     # RecordSet Methods
     def _find_recordsets(self, context, criterion, one=False, marker=None,
                          limit=None, sort_key=None, sort_dir=None,
-                         force_index=False):
+                         force_index=False, apply_tenant_criteria=True):
 
         # Check to see if the criterion can use the reverse_name column
         criterion = self._rname_check(criterion)
 
-        if criterion is not None \
-                and not criterion.get('zones_deleted', True):
+        if criterion is not None and not criterion.get('zones_deleted', True):
             # remove 'zones_deleted' from the criterion, as _apply_criterion
             # assumes each key in criterion to be a column name.
             del criterion['zones_deleted']
@@ -608,16 +670,22 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             rjoin = tables.recordsets.join(
                 tables.zones,
                 tables.recordsets.c.zone_id == tables.zones.c.id)
-            query = select([tables.recordsets]).select_from(rjoin).\
+            query = (
+                select([tables.recordsets]).select_from(rjoin).
                 where(tables.zones.c.deleted == '0')
+            )
 
             recordsets = self._find(
                 context, tables.recordsets, objects.RecordSet,
                 objects.RecordSetList, exceptions.RecordSetNotFound, criterion,
-                one, marker, limit, sort_key, sort_dir, query)
+                one, marker, limit, sort_key, sort_dir, query,
+                apply_tenant_criteria=apply_tenant_criteria,
+            )
 
             recordsets.records = self._find_records(
-                context, {'recordset_id': recordsets.id})
+                context, {'recordset_id': recordsets.id},
+                apply_tenant_criteria=apply_tenant_criteria,
+            )
 
             recordsets.obj_reset_changes(['records'])
 
@@ -626,7 +694,9 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                     context, criterion, tables.zones, tables.recordsets,
                     tables.records, limit=limit, marker=marker,
                     sort_key=sort_key, sort_dir=sort_dir,
-                    force_index=force_index)
+                    force_index=force_index,
+                    apply_tenant_criteria=apply_tenant_criteria,
+            )
 
             recordsets.total_count = tc
 
@@ -642,10 +712,12 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             tables.recordsets,
             tables.records.c.recordset_id == tables.recordsets.c.id)
 
-        query = select([tables.recordsets.c.id, tables.recordsets.c.type,
-                        tables.recordsets.c.ttl, tables.recordsets.c.name,
-                        tables.records.c.data, tables.records.c.action]).\
+        query = (
+            select([tables.recordsets.c.id, tables.recordsets.c.type,
+                    tables.recordsets.c.ttl, tables.recordsets.c.name,
+                    tables.records.c.data, tables.records.c.action]).
             select_from(rjoin).where(tables.records.c.action != 'DELETE')
+        )
 
         query = query.order_by(tables.recordsets.c.id)
 
@@ -655,14 +727,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         return raw_rows
 
     def create_recordset(self, context, zone_id, recordset):
-        # Fetch the zone as we need the tenant_id
-        zone = self._find_zones(context, {'id': zone_id}, one=True)
-
-        recordset.tenant_id = zone.tenant_id
+        recordset.tenant_id = context.project_id
         recordset.zone_id = zone_id
 
         # Patch in the reverse_name column
-        extra_values = {"reverse_name": recordset.name[::-1]}
+        extra_values = {'reverse_name': recordset.name[::-1]}
 
         recordset = self._create(
             tables.recordsets, recordset, exceptions.DuplicateRecordSet,
@@ -688,9 +757,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             tables.recordsets,
             tables.records.c.recordset_id == tables.recordsets.c.id)
 
-        query = select([tables.recordsets.c.name, tables.recordsets.c.ttl,
-                        tables.recordsets.c.type, tables.records.c.data]).\
+        query = (
+            select([tables.recordsets.c.name, tables.recordsets.c.ttl,
+                    tables.recordsets.c.type, tables.records.c.data]).
             select_from(rjoin)
+        )
 
         query = query.order_by(tables.recordsets.c.created_at)
 
@@ -699,17 +770,18 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
         return raw_rows
 
-    def get_recordset(self, context, recordset_id):
-        return self._find_recordsets(context, {'id': recordset_id}, one=True)
-
     def find_recordsets(self, context, criterion=None, marker=None, limit=None,
-                        sort_key=None, sort_dir=None, force_index=False):
-        return self._find_recordsets(context, criterion, marker=marker,
-                                     sort_dir=sort_dir, sort_key=sort_key,
-                                     limit=limit, force_index=force_index)
+                        sort_key=None, sort_dir=None, force_index=False,
+                        apply_tenant_criteria=True):
+        return self._find_recordsets(
+            context, criterion, marker=marker, sort_dir=sort_dir,
+            sort_key=sort_key, limit=limit, force_index=force_index,
+            apply_tenant_criteria=apply_tenant_criteria)
 
-    def find_recordset(self, context, criterion):
-        return self._find_recordsets(context, criterion, one=True)
+    def find_recordset(self, context, criterion, apply_tenant_criteria=True):
+        return self._find_recordsets(
+            context, criterion, one=True,
+            apply_tenant_criteria=apply_tenant_criteria)
 
     def update_recordset(self, context, recordset):
         recordset = self._update(
@@ -771,9 +843,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             tables.zones,
             tables.recordsets.c.zone_id == tables.zones.c.id)
 
-        query = select([func.count(tables.recordsets.c.id)]).\
-            select_from(rjoin).\
+        query = (
+            select([func.count(tables.recordsets.c.id)]).
+            select_from(rjoin).
             where(tables.zones.c.deleted == '0')
+        )
 
         query = self._apply_criterion(tables.recordsets, query, criterion)
         query = self._apply_tenant_criteria(context, tables.recordsets, query)
@@ -789,27 +863,27 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
     # Record Methods
     def _find_records(self, context, criterion, one=False, marker=None,
-                      limit=None, sort_key=None, sort_dir=None):
+                      limit=None, sort_key=None, sort_dir=None,
+                      apply_tenant_criteria=True):
         return self._find(
             context, tables.records, objects.Record, objects.RecordList,
             exceptions.RecordNotFound, criterion, one, marker, limit,
-            sort_key, sort_dir)
+            sort_key, sort_dir,
+            apply_tenant_criteria=apply_tenant_criteria,
+        )
 
     def _recalculate_record_hash(self, record):
         """
         Calculates the hash of the record, used to ensure record uniqueness.
         """
         md5sum = md5(usedforsecurity=False)
-        md5sum.update(("%s:%s" % (record.recordset_id,
+        md5sum.update(('%s:%s' % (record.recordset_id,
                                   record.data)).encode('utf-8'))
 
         return md5sum.hexdigest()
 
     def create_record(self, context, zone_id, recordset_id, record):
-        # Fetch the zone as we need the tenant_id
-        zone = self._find_zones(context, {'id': zone_id}, one=True)
-
-        record.tenant_id = zone.tenant_id
+        record.tenant_id = context.project_id
         record.zone_id = zone_id
         record.recordset_id = recordset_id
         record.hash = self._recalculate_record_hash(record)
@@ -849,9 +923,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             tables.zones,
             tables.records.c.zone_id == tables.zones.c.id)
 
-        query = select([func.count(tables.records.c.id)]).\
-            select_from(rjoin).\
+        query = (
+            select([func.count(tables.records.c.id)]).
+            select_from(rjoin).
             where(tables.zones.c.deleted == '0')
+        )
 
         query = self._apply_criterion(tables.records, query, criterion)
         query = self._apply_tenant_criteria(context, tables.records, query)
@@ -1069,19 +1145,6 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         return self._create(tables.pool_ns_records, pool_ns_record,
                             exceptions.DuplicatePoolNsRecord)
 
-    def get_pool_ns_record(self, context, pool_ns_record_id):
-        return self._find_pool_ns_records(
-            context, {'id': pool_ns_record_id}, one=True)
-
-    def find_pool_ns_records(self, context, criterion=None, marker=None,
-                             limit=None, sort_key=None, sort_dir=None):
-        return self._find_pool_ns_records(context, criterion, marker=marker,
-                                          limit=limit, sort_key=sort_key,
-                                          sort_dir=sort_dir)
-
-    def find_pool_ns_record(self, context, criterion):
-        return self._find_pool_ns_records(context, criterion, one=True)
-
     def update_pool_ns_record(self, context, pool_ns_record):
         return self._update(context, tables.pool_ns_records, pool_ns_record,
                             exceptions.DuplicatePoolNsRecord,
@@ -1118,8 +1181,8 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     def find_pool_nameservers(self, context, criterion=None, marker=None,
                    limit=None, sort_key=None, sort_dir=None):
         return self._find_pool_nameservers(context, criterion, marker=marker,
-                                          limit=limit, sort_key=sort_key,
-                                          sort_dir=sort_dir)
+                                           limit=limit, sort_key=sort_key,
+                                           sort_dir=sort_dir)
 
     def find_pool_nameserver(self, context, criterion):
         return self._find_pool_nameservers(context, criterion, one=True)
@@ -1197,8 +1260,8 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     def find_pool_targets(self, context, criterion=None, marker=None,
                           limit=None, sort_key=None, sort_dir=None):
         return self._find_pool_targets(context, criterion, marker=marker,
-                                limit=limit, sort_key=sort_key,
-                                sort_dir=sort_dir)
+                                       limit=limit, sort_key=sort_key,
+                                       sort_dir=sort_dir)
 
     def find_pool_target(self, context, criterion):
         return self._find_pool_targets(context, criterion, one=True)
@@ -1210,7 +1273,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                                   'targets', 'also_notifies')
 
         # Gather the pool ID's we have
-        finder = getattr(self, "_find_pool_%s" % attribute_name)
+        finder = getattr(self, '_find_pool_%s' % attribute_name)
         have_items = set()
         for r in finder(context, {'pool_id': pool.id}):
             have_items.add(r.id)
@@ -1247,17 +1310,17 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             singular = attribute_name[:-1]
 
         # Delete items
-        fn = getattr(self, "delete_pool_%s" % singular)
+        fn = getattr(self, 'delete_pool_%s' % singular)
         for item_id in have_items - keep_items:
             fn(context, item_id)
 
         # Update items
-        fn = getattr(self, "update_pool_%s" % singular)
+        fn = getattr(self, 'update_pool_%s' % singular)
         for item in update_items:
             fn(context, item)
 
         # Create items
-        fn = getattr(self, "create_pool_%s" % singular)
+        fn = getattr(self, 'create_pool_%s' % singular)
         for item in create_items:
             fn(context, pool.id, item)
 
@@ -1267,7 +1330,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         assert attribute_name in ('options', 'masters')
 
         # Gather the pool ID's we have
-        finder = getattr(self, "_find_pool_target_%s" % attribute_name)
+        finder = getattr(self, '_find_pool_target_%s' % attribute_name)
         have_items = set()
         for r in finder(context, {'pool_target_id': pool_target.id}):
             have_items.add(r.id)
@@ -1301,17 +1364,17 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         singular = attribute_name[:-1]
 
         # Delete items
-        fn = getattr(self, "delete_pool_target_%s" % singular)
+        fn = getattr(self, 'delete_pool_target_%s' % singular)
         for item_id in have_items - keep_items:
             fn(context, item_id)
 
         # Update items
-        fn = getattr(self, "update_pool_target_%s" % singular)
+        fn = getattr(self, 'update_pool_target_%s' % singular)
         for item in update_items:
             fn(context, item)
 
         # Create items
-        fn = getattr(self, "create_pool_target_%s" % singular)
+        fn = getattr(self, 'create_pool_target_%s' % singular)
         for item in create_items:
             fn(context, pool_target.id, item)
 
@@ -1356,19 +1419,6 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         return self._create(tables.pool_target_options, pool_target_option,
                             exceptions.DuplicatePoolTargetOption)
 
-    def get_pool_target_option(self, context, pool_target_option_id):
-        return self._find_pool_target_options(
-            context, {'id': pool_target_option_id}, one=True)
-
-    def find_pool_target_options(self, context, criterion=None, marker=None,
-                                 limit=None, sort_key=None, sort_dir=None):
-        return self._find_pool_target_options(
-            context, criterion, marker=marker, limit=limit, sort_key=sort_key,
-            sort_dir=sort_dir)
-
-    def find_pool_target_option(self, context, criterion):
-        return self._find_pool_target_options(context, criterion, one=True)
-
     def update_pool_target_option(self, context, pool_target_option):
         return self._update(
             context, tables.pool_target_options, pool_target_option,
@@ -1401,19 +1451,6 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         return self._create(tables.pool_target_masters, pool_target_master,
                             exceptions.DuplicatePoolTargetMaster)
 
-    def get_pool_target_master(self, context, pool_target_master_id):
-        return self._find_pool_target_masters(
-            context, {'id': pool_target_master_id}, one=True)
-
-    def find_pool_target_masters(self, context, criterion=None, marker=None,
-                                 limit=None, sort_key=None, sort_dir=None):
-        return self._find_pool_target_masters(
-            context, criterion, marker=marker, limit=limit, sort_key=sort_key,
-            sort_dir=sort_dir)
-
-    def find_pool_target_master(self, context, criterion):
-        return self._find_pool_target_masters(context, criterion, one=True)
-
     def update_pool_target_master(self, context, pool_target_master):
         return self._update(
             context, tables.pool_target_masters, pool_target_master,
@@ -1484,7 +1521,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             tables.zone_transfer_requests.c.zone_id == tables.zones.c.id)
 
         query = select(
-            [table, tables.zones.c.name.label("zone_name")]
+            [table, tables.zones.c.name.label('zone_name')]
         ).select_from(ljoin)
 
         if not context.all_tenants:
@@ -1513,8 +1550,8 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     def create_zone_transfer_request(self, context, zone_transfer_request):
 
         try:
-            criterion = {"zone_id": zone_transfer_request.zone_id,
-                         "status": "ACTIVE"}
+            criterion = {'zone_id': zone_transfer_request.zone_id,
+                         'status': 'ACTIVE'}
             self.find_zone_transfer_request(
                 context, criterion)
         except exceptions.ZoneTransferRequestNotFound:
@@ -1548,7 +1585,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
     def update_zone_transfer_request(self, context, zone_transfer_request):
 
-        zone_transfer_request.obj_reset_changes(('zone_name'))
+        zone_transfer_request.obj_reset_changes('zone_name')
 
         updated_zt_request = self._update(
             context,
@@ -1655,7 +1692,7 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
     # Zone Import Methods
     def _find_zone_imports(self, context, criterion, one=False, marker=None,
-                   limit=None, sort_key=None, sort_dir=None):
+                           limit=None, sort_key=None, sort_dir=None):
         if not criterion:
             criterion = {}
         criterion['task_type'] = 'IMPORT'
@@ -1676,13 +1713,13 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
     def get_zone_import(self, context, zone_import_id):
         return self._find_zone_imports(context, {'id': zone_import_id},
-                                     one=True)
+                                       one=True)
 
     def find_zone_imports(self, context, criterion=None, marker=None,
                   limit=None, sort_key=None, sort_dir=None):
         return self._find_zone_imports(context, criterion, marker=marker,
-                               limit=limit, sort_key=sort_key,
-                               sort_dir=sort_dir)
+                                       limit=limit, sort_key=sort_key,
+                                       sort_dir=sort_dir)
 
     def find_zone_import(self, context, criterion):
         return self._find_zone_imports(context, criterion, one=True)
@@ -1695,13 +1732,13 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     def delete_zone_import(self, context, zone_import_id):
         # Fetch the existing zone_import, we'll need to return it.
         zone_import = self._find_zone_imports(context, {'id': zone_import_id},
-                                one=True)
+                                              one=True)
         return self._delete(context, tables.zone_tasks, zone_import,
-                    exceptions.ZoneImportNotFound)
+                            exceptions.ZoneImportNotFound)
 
     # Zone Export Methods
     def _find_zone_exports(self, context, criterion, one=False, marker=None,
-                   limit=None, sort_key=None, sort_dir=None):
+                           limit=None, sort_key=None, sort_dir=None):
         if not criterion:
             criterion = {}
         criterion['task_type'] = 'EXPORT'
@@ -1721,13 +1758,13 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
     def get_zone_export(self, context, zone_export_id):
         return self._find_zone_exports(context, {'id': zone_export_id},
-                                     one=True)
+                                       one=True)
 
     def find_zone_exports(self, context, criterion=None, marker=None,
-                  limit=None, sort_key=None, sort_dir=None):
+                          limit=None, sort_key=None, sort_dir=None):
         return self._find_zone_exports(context, criterion, marker=marker,
-                               limit=limit, sort_key=sort_key,
-                               sort_dir=sort_dir)
+                                       limit=limit, sort_key=sort_key,
+                                       sort_dir=sort_dir)
 
     def find_zone_export(self, context, criterion):
         return self._find_zone_exports(context, criterion, one=True)
@@ -1740,9 +1777,9 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     def delete_zone_export(self, context, zone_export_id):
         # Fetch the existing zone_export, we'll need to return it.
         zone_export = self._find_zone_exports(context, {'id': zone_export_id},
-                                one=True)
+                                              one=True)
         return self._delete(context, tables.zone_tasks, zone_export,
-                    exceptions.ZoneExportNotFound)
+                            exceptions.ZoneExportNotFound)
 
     def count_zone_tasks(self, context, criterion=None):
         query = select([func.count(tables.zone_tasks.c.id)])
@@ -1787,25 +1824,9 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             exceptions.DuplicateServiceStatus,
             exceptions.ServiceStatusNotFound)
 
-    # diagnostics
-    def ping(self, context):
-        start_time = time.time()
-
-        try:
-            result = self.engine.execute('SELECT 1').first()
-        except Exception:
-            status = False
-        else:
-            status = True if result[0] == 1 else False
-
-        return {
-            'status': status,
-            'rtt': "%f" % (time.time() - start_time)
-        }
-
     # Reverse Name utils
     def _rname_check(self, criterion):
         # If the criterion has 'name' in it, switch it out for reverse_name
-        if criterion is not None and criterion.get('name', "").startswith('*'):
+        if criterion is not None and criterion.get('name', '').startswith('*'):
             criterion['reverse_name'] = criterion.pop('name')[::-1]
         return criterion
