@@ -117,7 +117,7 @@ class TestCase(base.BaseTestCase):
     tsigkey_fixtures = [{
         'name': 'test-key-one',
         'algorithm': 'hmac-md5',
-        'secret': 'SomeOldSecretKey',
+        'secret': 'SomeSecretKey',
         'scope': 'POOL',
         'resource_id': '6ca6baef-3305-4ad0-a52b-a82df5752b62',
     }, {
@@ -221,7 +221,7 @@ class TestCase(base.BaseTestCase):
 
     blacklist_fixtures = [{
         'pattern': 'blacklisted.com.',
-        'description': u'This is a comment',
+        'description': 'This is a comment',
     }, {
         'pattern': 'blacklisted.net.'
     }, {
@@ -230,13 +230,13 @@ class TestCase(base.BaseTestCase):
 
     pool_fixtures = [
         {'name': 'Pool-One',
-         'description': u'Pool-One description',
+         'description': 'Pool-One description',
          'attributes': [{'key': 'scope', 'value': 'public'}],
          'ns_records': [{'priority': 1, 'hostname': 'ns1.example.org.'},
                         {'priority': 2, 'hostname': 'ns2.example.org.'}]},
 
         {'name': 'Pool-Two',
-         'description': u'Pool-Two description',
+         'description': 'Pool-Two description',
          'attributes': [{'key': 'scope', 'value': 'public'}],
          'ns_records': [{'priority': 1, 'hostname': 'ns1.example.org.'}]},
     ]
@@ -268,10 +268,10 @@ class TestCase(base.BaseTestCase):
     pool_target_fixtures = [
         {'pool_id': default_pool_id,
          'type': "fake",
-         'description': u"FooBar"},
+         'description': "FooBar"},
         {'pool_id': default_pool_id,
          'type': "fake",
-         'description': u"BarFoo"},
+         'description': "BarFoo"},
     ]
 
     pool_also_notify_fixtures = [
@@ -283,6 +283,14 @@ class TestCase(base.BaseTestCase):
          'port': 53},
     ]
 
+    shared_zone_fixtures = [
+        {
+            "target_project_id": "target_project_id",
+            "zone_id": None,
+            "project_id": "project_id",
+        }
+    ]
+
     zone_transfers_request_fixtures = [{
         "description": "Test Transfer",
     }, {
@@ -421,7 +429,7 @@ class TestCase(base.BaseTestCase):
         ])
 
         pool.targets = objects.PoolTargetList.from_list([
-            {'type': 'fake', u'description': u"Fake PoolTarget for Tests"}
+            {'type': 'fake', 'description': "Fake PoolTarget for Tests"}
         ])
 
         # Save the default pool
@@ -628,6 +636,13 @@ class TestCase(base.BaseTestCase):
         _values.update(values)
         return _values
 
+    def get_shared_zone_fixture(self, fixture=0, values=None):
+        values = values or {}
+
+        _values = copy.copy(self.shared_zone_fixtures[fixture])
+        _values.update(values)
+        return _values
+
     def update_service_status(self, **kwargs):
         context = kwargs.pop('context', self.admin_context)
         fixture = kwargs.pop('fixture', 0)
@@ -830,6 +845,16 @@ class TestCase(base.BaseTestCase):
 
         return zone_import
 
+    def share_zone(self, **kwargs):
+        context = kwargs.pop('context', self.admin_context)
+        fixture = kwargs.pop('fixture', 0)
+
+        values = self.get_shared_zone_fixture(fixture, values=kwargs)
+
+        return self.central_service.share_zone(
+            context, kwargs['zone_id'], objects.SharedZone.from_dict(values)
+        )
+
     def _ensure_interface(self, interface, implementation):
         for name in interface.__abstractmethods__:
             in_arginfo = inspect.getfullargspec(getattr(interface, name))
