@@ -21,9 +21,9 @@ import oslo_messaging as messaging
 
 from designate import backend
 from designate.central import rpcapi as central_api
+from designate.common.decorators import rpc
 from designate.context import DesignateContext
 from designate import exceptions
-from designate import rpc
 from designate import service
 from designate import storage
 from designate.worker import processing
@@ -42,7 +42,7 @@ class AlsoNotifyTask(object):
 
 
 class Service(service.RPCService):
-    RPC_API_VERSION = '1.0'
+    RPC_API_VERSION = '1.2'
 
     target = messaging.Target(version=RPC_API_VERSION)
 
@@ -91,12 +91,12 @@ class Service(service.RPCService):
                 if len(pool.targets) > 0:
                     has_targets = True
                 else:
-                    LOG.error("No targets for %s found.", pool)
+                    LOG.error('No targets for %s found.', pool)
                     time.sleep(5)
 
             # Pool data may not have migrated to the DB yet
             except exceptions.PoolNotFound:
-                LOG.error("Pool ID %s not found.", pool_id)
+                LOG.error('Pool ID %s not found.', pool_id)
                 time.sleep(5)
             # designate-central service may not have started yet
             except messaging.exceptions.MessagingTimeout:
@@ -130,7 +130,7 @@ class Service(service.RPCService):
 
     def get_pool(self, pool_id):
         if pool_id not in self.pools_map:
-            LOG.info("Lazily loading pool %s", pool_id)
+            LOG.info('Lazily loading pool %s', pool_id)
             self.pools_map[pool_id] = self.load_pool(pool_id)
         return self.pools_map[pool_id]
 
@@ -141,12 +141,12 @@ class Service(service.RPCService):
     def stop(self, graceful=True):
         super(Service, self).stop(graceful)
 
-    def _do_zone_action(self, context, zone):
+    def _do_zone_action(self, context, zone, zone_params=None):
         pool = self.get_pool(zone.pool_id)
-        all_tasks = []
-        all_tasks.append(zonetasks.ZoneAction(
-            self.executor, context, pool, zone, zone.action
-        ))
+        all_tasks = [
+            zonetasks.ZoneAction(self.executor, context, pool, zone,
+                                 zone.action, zone_params)
+        ]
 
         # Send a NOTIFY to each also-notifies
         for also_notify in pool.also_notifies:
@@ -177,13 +177,17 @@ class Service(service.RPCService):
         self._do_zone_action(context, zone)
 
     @rpc.expected_exceptions()
-    def delete_zone(self, context, zone):
+    def delete_zone(self, context, zone, hard_delete=False):
         """
         :param context: Security context information.
         :param zone: Zone to be deleted
+        :param hard_delete: Zone resources (files) to be deleted or not
         :return: None
         """
-        self._do_zone_action(context, zone)
+        zone_params = {}
+        if hard_delete:
+            zone_params.update({'hard_delete': True})
+        self._do_zone_action(context, zone, zone_params)
 
     @rpc.expected_exceptions()
     def recover_shard(self, context, begin, end):
@@ -206,3 +210,26 @@ class Service(service.RPCService):
         return self.executor.run(zonetasks.ExportZone(
             self.executor, context, zone, export
         ))
+
+    @rpc.expected_exceptions()
+    def perform_zone_xfr(self, context, zone, servers=None):
+        """
+        :param zone: Zone to be exported
+        :param servers:
+        :return: None
+        """
+        return self.executor.run(zonetasks.ZoneXfr(
+            self.executor, context, zone, servers
+        ))
+
+    @rpc.expected_exceptions()
+    def get_serial_number(self, context, zone, host, port):
+        """
+        :param zone: Zone to get serial number
+        :param host:
+        :param port:
+        :return: tuple
+        """
+        return self.executor.run(zonetasks.GetZoneSerial(
+            self.executor, context, zone, host, port,
+        ))[0]
